@@ -24,15 +24,17 @@
 #define PIECETEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace KPieceTable {
+
+namespace KPieceTable
+{
 
 class PieceTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testSimpleConstructor();
     void testFullConstructor();
     void testSplitAt();
