@@ -24,15 +24,17 @@
 #define BYTEARRAYMODELTEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 class ByteArrayModelTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testNothing();
 };
 
