@@ -24,15 +24,17 @@
 #define CHARCODECTEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 class CharCodecTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testCreateCodec_data();
     void testCreateCodec();
     void testEncodeDecode_data();
