@@ -24,17 +24,19 @@
 #define FIXEDSIZEBYTEARRAYMODELTEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 class FixedSizeByteArrayModelTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testCompare();
-    // void testCopy();
+    //void testCopy();
 
 };
 
