@@ -1,134 +1,151 @@
 /*
     This file is part of the Okteta Gui library, made within the KDE community.
 
-    SPDX-FileCopyrightText: 2006 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2006 Friedrich W. H. Kossebau <kossebau@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "coordrangetest.hpp"
+#include "coordrangetest.h"
 
 // test object
-#include <coordrange.hpp>
+#include <coordrange.h>
 // Qt
-#include <QTest>
+#include <QtTest/QtTest>
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 // local variables
-static constexpr LinePosition Pos1 = 15;
-static constexpr LinePosition Pos2 = 25;
-static constexpr Line Line1 = 10;
-static constexpr LineSize LineCount = 10;
-static constexpr Line Line2 = Line1 + LineCount - 1;
-static constexpr Coord Start(Pos1, Line1);
-static constexpr Coord End(Pos2, Line2);
+static const LinePosition Pos1 = 15;
+static const LinePosition Pos2 = 25;
+static const Line Line1 = 10;
+static const LineSize LineCount = 10;
+static const Line Line2 = Line1 + LineCount - 1;
+static Coord Start( Pos1, Line1 );
+static Coord End(   Pos2, Line2 );
+
+static const Size BufferWidth = Pos2 + 5;
 
-static constexpr Size BufferWidth = Pos2 + 5;
 
 void CoordRangeTest::testConstructorByCoords()
 {
-    CoordRange coordRange(Start, End);
-    QCOMPARE(coordRange.start(), Start);
-    QCOMPARE(coordRange.end(),   End);
-    QCOMPARE(coordRange.lines(), LineCount);
-    QVERIFY(coordRange.isValid());
+    CoordRange coordRange( Start, End );
+    QCOMPARE( coordRange.start(), Start );
+    QCOMPARE( coordRange.end(),   End );
+    QCOMPARE( coordRange.lines(), LineCount );
+    QVERIFY( coordRange.isValid() );
 }
 
 void CoordRangeTest::testConstructorByPosLines()
 {
-    LinePositionRange positions(Pos1, Pos2);
-    LineRange lines(Line1, Line2);
+    LinePositionRange positions( Pos1, Pos2 );
+    LineRange lines( Line1, Line2 );
 
-    CoordRange coordRange(positions, lines);
-    QCOMPARE(coordRange.start(), Coord(Pos1, Line1));
-    QCOMPARE(coordRange.end(),   Coord(Pos2, Line2));
-    QCOMPARE(coordRange.lines(), LineCount);
-    QVERIFY(coordRange.isValid());
+    CoordRange coordRange( positions, lines );
+    QCOMPARE( coordRange.start(), Coord(Pos1,Line1) );
+    QCOMPARE( coordRange.end(),   Coord(Pos2,Line2) );
+    QCOMPARE( coordRange.lines(), LineCount );
+    QVERIFY( coordRange.isValid() );
 }
 
 void CoordRangeTest::testSimpleConstructor()
 {
     CoordRange coordRange;
-    QVERIFY(coordRange.isEmpty());
-    QVERIFY(!coordRange.isValid());
+    QVERIFY( coordRange.isEmpty() );
+    QVERIFY( !coordRange.isValid() );
 }
 
 void CoordRangeTest::testSetGetStart()
 {
     CoordRange coordRange;
-    coordRange.setStart(Start);
-    QCOMPARE(coordRange.start(), Start);
+    coordRange.setStart( Start );
+    QCOMPARE( coordRange.start(), Start );
 }
 
 void CoordRangeTest::testSetGetEnd()
 {
     CoordRange coordRange;
-    coordRange.setEnd(End);
-    QCOMPARE(coordRange.end(), End);
+    coordRange.setEnd( End );
+    QCOMPARE( coordRange.end(), End );
 }
 
 void CoordRangeTest::testIsEmpty()
 {
-    CoordRange coordRange(Start, End);
-    QVERIFY(!coordRange.isEmpty());
+    CoordRange coordRange( Start, End );
+    QVERIFY( !coordRange.isEmpty() );
     coordRange.unset();
-    QVERIFY(coordRange.isEmpty());
+    QVERIFY( coordRange.isEmpty() );
 }
 
 void CoordRangeTest::testCompare()
 {
-    CoordRange coordRange(Start, End);
+    CoordRange coordRange( Start, End );
     // same
-    CoordRange otherCoordRange(Start, End);
-    QVERIFY(coordRange == otherCoordRange);
+    CoordRange otherCoordRange( Start, End );
+    QVERIFY( coordRange == otherCoordRange );
     // different start
-    otherCoordRange.set(Coord(Pos1 + 1, Line1), End);
-    QVERIFY(!(coordRange == otherCoordRange));
+    otherCoordRange.set( Coord(Pos1+1,Line1), End );
+    QVERIFY( !(coordRange == otherCoordRange) );
     // different end
-    otherCoordRange.set(Start, Coord(Pos2 + 1, Line2));
-    QVERIFY(!(coordRange == otherCoordRange));
+    otherCoordRange.set(Start, Coord(Pos2+1,Line2));
+    QVERIFY( !(coordRange == otherCoordRange) );
 }
 
 void CoordRangeTest::testIncludes()
 {
-    CoordRange coordRange(Start, End);
+    CoordRange coordRange( Start, End );
     // at start
     Coord coord = coordRange.start();
-    QVERIFY(coordRange.includes(coord));
+    QVERIFY( coordRange.includes(coord) );
     // before start
     coord.goLeft();
-    QVERIFY(!coordRange.includes(coord));
+    QVERIFY( !coordRange.includes(coord) );
     // at end
     coord = coordRange.end();
-    QVERIFY(coordRange.includes(coord));
+    QVERIFY( coordRange.includes(coord) );
     // behind end
     coord.goRight();
-    QVERIFY(!coordRange.includes(coord));
+    QVERIFY( !coordRange.includes(coord) );
 }
 
 void CoordRangeTest::testIncludesLine()
 {
-    CoordRange coordRange(Start, End);
+    CoordRange coordRange( Start, End );
     // at start
     Line L = coordRange.start().line();
-    QVERIFY(coordRange.includesLine(L));
+    QVERIFY( coordRange.includesLine(L) );
     // before start
     --L;
-    QVERIFY(!coordRange.includesLine(L));
+    QVERIFY( !coordRange.includesLine(L) );
     // at end
     L = coordRange.end().line();
-    QVERIFY(coordRange.includesLine(L));
+    QVERIFY( coordRange.includesLine(L) );
     // behind end
     ++L;
-    QVERIFY(!coordRange.includesLine(L));
+    QVERIFY( !coordRange.includesLine(L) );
 }
 
 void CoordRangeTest::testWidth()
 {
-    CoordRange coordRange(Start, End);
-    const Size width = BufferWidth * (LineCount - 1) - Start.pos() + End.pos() + 1;
-    QCOMPARE(coordRange.width(BufferWidth), width);
+    CoordRange coordRange( Start, End );
+    const Size width = BufferWidth*(LineCount-1) - Start.pos() + End.pos()+1;
+    QCOMPARE( coordRange.width(BufferWidth), width );
 }
 
 /*
@@ -441,6 +458,4 @@ void CoordRangeTest::testIsJoinable()
 
 }
 
-QTEST_MAIN(Okteta::CoordRangeTest)
-
-#include "moc_coordrangetest.cpp"
+QTEST_MAIN( Okteta::CoordRangeTest )
