@@ -24,22 +24,24 @@
 #define STATISTICTABLEMODEL_H
 
 // Okteta core
-#include <okteta/oktetacore.h>
+#include <oktetacore.h>
 // Qt
-#include <QAbstractTableModel>
+#include <QtCore/QAbstractTableModel>
 
 namespace Okteta {
 class CharCodec;
 class ValueCodec;
 }
 
-namespace Kasten {
+
+namespace Kasten2
+{
 
 class StatisticTableModel : public QAbstractTableModel
 {
-    Q_OBJECT
+  Q_OBJECT
 
-public:
+  public:
     enum ColumnIds
     {
         ValueId = 0,
@@ -49,37 +51,35 @@ public:
         NoOfIds = 4 // TODO: what pattern is usually used to mark number of ids?
     };
 
-public:
-    explicit StatisticTableModel(int* byteCount, QObject* parent = nullptr);
-    ~StatisticTableModel() override;
+  public:
+    explicit StatisticTableModel( int *byteCount, QObject *parent = 0 );
+    virtual ~StatisticTableModel();
 
-public: // QAbstractTableModel API
-    int rowCount(const QModelIndex& parent) const override;
-    int columnCount(const QModelIndex& parent) const override;
-    QVariant data(const QModelIndex& index, int role) const override;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+  public: // QAbstractTableModel API
+    virtual int rowCount( const QModelIndex &parent ) const;
+    virtual int columnCount( const QModelIndex &parent ) const;
+    virtual QVariant data( const QModelIndex &index, int role ) const;
+    virtual QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
 
-public:
-    void update(int size);
+  public:
+    void update( int size );
 
-public Q_SLOTS:
-    void setCharCodec(const QString& codecName);
-    void setValueCoding(int valueCoding);
-    void setSubstituteChar(QChar substituteChar);
-    void setUndefinedChar(QChar undefinedChar);
+  public Q_SLOTS:
+    void setCharCodec( const QString &codecName );
+    void setValueCoding( int valueCoding );
+    void setUndefinedChar( QChar undefinedChar );
 
-Q_SIGNALS:
+  Q_SIGNALS:
     void headerChanged();
-    void sizeChanged(int size);
+    void sizeChanged( int size );
 
-private:
+  private:
     int mSize;
-    int* mByteCount;
+    int *mByteCount;
 
     Okteta::ValueCoding mValueCoding;
-    Okteta::ValueCodec* mValueCodec;
-    Okteta::CharCodec* mCharCodec;
-    QChar mSubstituteChar;
+    Okteta::ValueCodec *mValueCodec;
+    Okteta::CharCodec *mCharCodec;
     QChar mUndefinedChar;
 };
 
