@@ -23,10 +23,10 @@
 #ifndef KFINDDIRECTION_H
 #define KFINDDIRECTION_H
 
-namespace Kasten {
-
-enum KFindDirection
+namespace Kasten2
 {
+
+enum KFindDirection {
     FindForward = 0,
     FindBackward = 1
 };
