@@ -25,21 +25,22 @@
 
 // lib
 #include "../types/float64.h"
-// Qt
-#include <QLineEdit>
+// KDE
+#include <KLineEdit>
 
-class Float64Editor : public QLineEdit
+
+class Float64Editor : public KLineEdit
 {
-    Q_OBJECT
-    Q_PROPERTY(Float64 data READ data WRITE setData USER true)
+  Q_OBJECT
+  Q_PROPERTY( Float64 data READ data WRITE setData USER true )
 
-public:
-    explicit Float64Editor(QWidget* parent);
+  public:
+    explicit Float64Editor( QWidget* parent );
 
-    ~Float64Editor() override;
+    virtual ~Float64Editor();
 
-public:
-    void setData(Float64 data);
+  public:
+    void setData( Float64 data );
     Float64 data() const;
 };
 
