@@ -25,21 +25,22 @@
 
 // lib
 #include "../types/utf8.h"
-// Qt
-#include <QLineEdit>
+// KDE
+#include <KLineEdit>
 
-class Utf8Editor : public QLineEdit
+
+class Utf8Editor : public KLineEdit
 {
-    Q_OBJECT
-    Q_PROPERTY(Utf8 data READ data WRITE setData USER true)
+  Q_OBJECT
+  Q_PROPERTY( Utf8 data READ data WRITE setData USER true )
 
-public:
-    explicit Utf8Editor(QWidget* parent);
+  public:
+    explicit Utf8Editor( QWidget* parent );
 
-    ~Utf8Editor() override;
+    virtual ~Utf8Editor();
 
-public:
-    void setData(Utf8 data);
+  public:
+    void setData( Utf8 data );
     Utf8 data() const;
 };
 
