@@ -24,30 +24,33 @@
 #define FLOAT64_H
 
 // Qt
-#include <QMetaType>
-#include <QString>
+#include <QtCore/QMetaType>
+#include <QtCore/QString>
+
 
 struct Float64
 {
-public:
-    Float64(double v);
+  public:
+    Float64( double v );
     Float64();
 
-public:
+  public:
     QString toString() const;
 
-public:
-    double value = 0;
+  public:
+    double value;
 };
 
-inline Float64::Float64() = default;
-inline Float64::Float64(double v) : value(v) {}
+
+inline Float64::Float64() : value( 0 ) {}
+inline Float64::Float64( double v ) : value( v ) {}
 
 inline QString Float64::toString() const
 {
-    return QString::number(value, 'e', 16);
+    return QString::number( value, 'e', 16 );
 }
 
-Q_DECLARE_METATYPE(Float64)
+
+Q_DECLARE_METATYPE( Float64 )
 
 #endif
